"""
Python module generated from Java source file org.bukkit.inventory.TransmuteRecipe

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import NamespacedKey
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class TransmuteRecipe(CraftingRecipe, ComplexRecipe):
    """
    Represents a recipe which will change the type of the input material when
    combined with an additional material, but preserve all custom data. Only the
    item type of the result stack will be used.
    
    Used for dyeing shulker boxes in Vanilla.
    """

    def __init__(self, key: "NamespacedKey", result: "Material", input: "RecipeChoice", material: "RecipeChoice"):
        """
        Create a transmute recipe to produce a result of the specified type.

        Arguments
        - key: the unique recipe key
        - result: the transmuted result material
        - input: the input ingredient
        - material: the additional ingredient
        """
        ...


    def getInput(self) -> "RecipeChoice":
        """
        Gets the input material, which will be transmuted.

        Returns
        - the input from transmutation
        """
        ...


    def getMaterial(self) -> "RecipeChoice":
        """
        Gets the additional material required to cause the transmutation.

        Returns
        - the ingredient material
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.SignChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block.sign import Side
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class SignChangeEvent(BlockEvent, Cancellable):
    """
    Called when a sign is changed by a player.
    
    If a Sign Change event is cancelled, the sign will not be changed.
    """

    def __init__(self, theBlock: "Block", thePlayer: "Player", theLines: list[str]):
        ...


    def __init__(self, theBlock: "Block", thePlayer: "Player", theLines: list[str], side: "Side"):
        ...


    def getPlayer(self) -> "Player":
        """
        Gets the player changing the sign involved in this event.

        Returns
        - the Player involved in this event
        """
        ...


    def getLines(self) -> list[str]:
        """
        Gets all of the lines of text from the sign involved in this event.

        Returns
        - the String array for the sign's lines new text
        """
        ...


    def getLine(self, index: int) -> str:
        """
        Gets a single line of text from the sign involved in this event.

        Arguments
        - index: index of the line to get

        Returns
        - the String containing the line of text associated with the
            provided index

        Raises
        - IndexOutOfBoundsException: thrown when the provided index is > 3
            or < 0
        """
        ...


    def setLine(self, index: int, line: str) -> None:
        """
        Sets a single line for the sign involved in this event

        Arguments
        - index: index of the line to set
        - line: text to set

        Raises
        - IndexOutOfBoundsException: thrown when the provided index is > 3
            or < 0
        """
        ...


    def getSide(self) -> "Side":
        """
        Returns which side is changed.

        Returns
        - the affected side of the sign
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.util.noise.SimplexOctaveGenerator

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Random
from org.bukkit import World
from org.bukkit.util.noise import *
from typing import Any, Callable, Iterable, Tuple


class SimplexOctaveGenerator(OctaveGenerator):
    """
    Creates simplex noise through unbiased octaves
    """

    def __init__(self, world: "World", octaves: int):
        """
        Creates a simplex octave generator for the given world

        Arguments
        - world: World to construct this generator for
        - octaves: Amount of octaves to create
        """
        ...


    def __init__(self, seed: int, octaves: int):
        """
        Creates a simplex octave generator for the given world

        Arguments
        - seed: Seed to construct this generator for
        - octaves: Amount of octaves to create
        """
        ...


    def __init__(self, rand: "Random", octaves: int):
        """
        Creates a simplex octave generator for the given Random

        Arguments
        - rand: Random object to construct this generator for
        - octaves: Amount of octaves to create
        """
        ...


    def setScale(self, scale: float) -> None:
        ...


    def getWScale(self) -> float:
        """
        Gets the scale used for each W-coordinates passed

        Returns
        - W scale
        """
        ...


    def setWScale(self, scale: float) -> None:
        """
        Sets the scale used for each W-coordinates passed

        Arguments
        - scale: New W scale
        """
        ...


    def noise(self, x: float, y: float, z: float, w: float, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - w: W-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, z: float, w: float, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - w: W-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...



"""
Python module generated from Java source file org.bukkit.command.MultipleCommandAlias

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class MultipleCommandAlias(Command):
    """
    Represents a command that delegates to one or more other commands
    """

    def __init__(self, name: str, commands: list["Command"]):
        ...


    def getCommands(self) -> list["Command"]:
        """
        Gets the commands associated with the multi-command alias.

        Returns
        - commands associated with alias
        """
        ...


    def execute(self, sender: "CommandSender", commandLabel: str, args: list[str]) -> bool:
        ...



from .VehicleDestroyEvent import VehicleDestroyEvent
from .VehicleEnterEvent import VehicleEnterEvent
from .VehicleBlockCollisionEvent import VehicleBlockCollisionEvent
from .VehicleMoveEvent import VehicleMoveEvent
from .VehicleCollisionEvent import VehicleCollisionEvent
from .VehicleExitEvent import VehicleExitEvent
from .VehicleCreateEvent import VehicleCreateEvent
from .VehicleUpdateEvent import VehicleUpdateEvent
from .VehicleEvent import VehicleEvent
from .VehicleEntityCollisionEvent import VehicleEntityCollisionEvent
from .VehicleDamageEvent import VehicleDamageEvent


"""
Python module generated from Java source file net.md_5.bungee.api.chat.TranslationProvider

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from net.md_5.bungee.api.chat import *
from typing import Any, Callable, Iterable, Tuple


class TranslationProvider:
    """
    An object capable of being translated by the client in a
    TranslatableComponent.
    """

    def getTranslationKey(self) -> str:
        """
        Get the translation key.

        Returns
        - the translation key
        """
        ...


    def asTranslatableComponent(self) -> "TranslatableComponent":
        """
        Get this translatable object as a TranslatableComponent.

        Returns
        - the translatable component
        """
        ...


    def asTranslatableComponent(self, *with: Tuple["Object", ...]) -> "TranslatableComponent":
        """
        Get this translatable object as a TranslatableComponent.

        Arguments
        - with: the String Strings and
        BaseComponent BaseComponents to use in the translation

        Returns
        - the translatable component
        """
        ...



"""
Python module generated from Java source file org.bukkit.HeightMap

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class HeightMap(Enum):
    """
    Further information regarding heightmaps.

    See
    - <a href="https://minecraft.wiki/w/Chunk_format">Minecraft Wiki</a>
    """

    MOTION_BLOCKING = 0
    """
    The highest block that blocks motion or contains a fluid.
    """
    MOTION_BLOCKING_NO_LEAVES = 1
    """
    The highest block that blocks motion or contains a fluid or is in the
    Tag.LEAVES.
    """
    OCEAN_FLOOR = 2
    """
    The highest non-air block, solid block.
    """
    OCEAN_FLOOR_WG = 3
    """
    The highest block that is neither air nor contains a fluid, for worldgen.
    """
    WORLD_SURFACE = 4
    """
    The highest non-air block.
    """
    WORLD_SURFACE_WG = 5
    """
    The highest non-air block, for worldgen.
    """



"""
Python module generated from Java source file org.bukkit.entity.Horse

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from org.bukkit.inventory import HorseInventory
from typing import Any, Callable, Iterable, Tuple


class Horse(AbstractHorse):
    """
    Represents a Horse.
    """

    def getColor(self) -> "Color":
        """
        Gets the horse's color.
        
        Colors only apply to horses, not to donkeys, mules, skeleton horses
        or undead horses.

        Returns
        - a Color representing the horse's group
        """
        ...


    def setColor(self, color: "Color") -> None:
        """
        Sets the horse's color.
        
        Attempting to set a color for any donkey, mule, skeleton horse or
        undead horse will not result in a change.

        Arguments
        - color: a Color for this horse
        """
        ...


    def getStyle(self) -> "Style":
        """
        Gets the horse's style.
        Styles determine what kind of markings or patterns a horse has.
        
        Styles only apply to horses, not to donkeys, mules, skeleton horses
        or undead horses.

        Returns
        - a Style representing the horse's style
        """
        ...


    def setStyle(self, style: "Style") -> None:
        """
        Sets the style of this horse.
        Styles determine what kind of markings or patterns a horse has.
        
        Attempting to set a style for any donkey, mule, skeleton horse or
        undead horse will not result in a change.

        Arguments
        - style: a Style for this horse
        """
        ...


    def isCarryingChest(self) -> bool:
        """
        Returns
        - carrying chest status

        Deprecated
        - see ChestedHorse
        """
        ...


    def setCarryingChest(self, chest: bool) -> None:
        """
        Arguments
        - chest: chest

        Deprecated
        - see ChestedHorse
        """
        ...


    def getInventory(self) -> "HorseInventory":
        ...


    class Variant(Enum):
        """
        Deprecated
        - different variants are differing classes
        """

        HORSE = 0
        """
        A normal horse
        """
        DONKEY = 1
        """
        A donkey
        """
        MULE = 2
        """
        A mule
        """
        UNDEAD_HORSE = 3
        """
        An undead horse
        """
        SKELETON_HORSE = 4
        """
        A skeleton horse
        """
        LLAMA = 5
        """
        Not really a horse :)
        """
        CAMEL = 6
        """
        Also not really a horse :)
        """


    class Color(Enum):
        """
        Represents the base color that the horse has.
        """

        WHITE = 0
        """
        Snow white
        """
        CREAMY = 1
        """
        Very light brown
        """
        CHESTNUT = 2
        """
        Chestnut
        """
        BROWN = 3
        """
        Light brown
        """
        BLACK = 4
        """
        Pitch black
        """
        GRAY = 5
        """
        Gray
        """
        DARK_BROWN = 6
        """
        Dark brown
        """


    class Style(Enum):
        """
        Represents the style, or markings, that the horse has.
        """

        NONE = 0
        """
        No markings
        """
        WHITE = 1
        """
        White socks or stripes
        """
        WHITEFIELD = 2
        """
        Milky splotches
        """
        WHITE_DOTS = 3
        """
        Round white dots
        """
        BLACK_DOTS = 4
        """
        Small black dots
        """



"""
Python module generated from Java source file org.bukkit.event.entity.EntityPlaceEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.inventory import EquipmentSlot
from typing import Any, Callable, Iterable, Tuple


class EntityPlaceEvent(EntityEvent, Cancellable):
    """
    Triggered when a entity is created in the world by a player "placing" an item
    on a block.
    
    Note that this event is currently only fired for four specific placements:
    armor stands, boats, minecarts, and end crystals.
    """

    def __init__(self, entity: "Entity", player: "Player", block: "Block", blockFace: "BlockFace", hand: "EquipmentSlot"):
        ...


    def __init__(self, entity: "Entity", player: "Player", block: "Block", blockFace: "BlockFace"):
        ...


    def getPlayer(self) -> "Player":
        """
        Returns the player placing the entity

        Returns
        - the player placing the entity
        """
        ...


    def getBlock(self) -> "Block":
        """
        Returns the block that the entity was placed on

        Returns
        - the block that the entity was placed on
        """
        ...


    def getBlockFace(self) -> "BlockFace":
        """
        Returns the face of the block that the entity was placed on

        Returns
        - the face of the block that the entity was placed on
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        Get the hand used to place the entity.

        Returns
        - the hand
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.Event

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.event import *
from org.bukkit.plugin import Plugin
from org.bukkit.plugin import PluginManager
from typing import Any, Callable, Iterable, Tuple


class Event:
    """
    Represents an event.
    
    All events require a static method named getHandlerList() which returns the same HandlerList as .getHandlers().

    See
    - PluginManager.registerEvents(Listener,Plugin)
    """

    def __init__(self):
        """
        The default constructor is defined for cleaner code. This constructor
        assumes the event is synchronous.
        """
        ...


    def __init__(self, isAsync: bool):
        """
        This constructor is used to explicitly declare an event as synchronous
        or asynchronous.

        Arguments
        - isAsync: True indicates the event will fire asynchronously, False
            by default from default constructor
        """
        ...


    def getEventName(self) -> str:
        """
        Convenience method for providing a user-friendly identifier. By
        default, it is the event's class's Class.getSimpleName()
        simple name.

        Returns
        - name of this event
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    def isAsynchronous(self) -> bool:
        """
        Any custom event that should not by synchronized with other events must
        use the specific constructor. These are the caveats of using an
        asynchronous event:
        
        - The event is never fired from inside code triggered by a
            synchronous event. Attempting to do so results in an java.lang.IllegalStateException.
        - However, asynchronous event handlers may fire synchronous or
            asynchronous events
        - The event may be fired multiple times simultaneously and in any
            order.
        - Any newly registered or unregistered handler is ignored after an
            event starts execution.
        - The handlers for this event may block for any length of time.
        - Some implementations may selectively declare a specific event use
            as asynchronous. This behavior should be clearly defined.
        - Asynchronous calls are not calculated in the plugin timing system.

        Returns
        - False by default, True if the event fires asynchronously
        """
        ...


    class Result(Enum):

        DENY = 0
        """
        Deny the event. Depending on the event, the action indicated by the
        event will either not take place or will be reverted. Some actions
        may not be denied.
        """
        DEFAULT = 1
        """
        Neither deny nor allow the event. The server will proceed with its
        normal handling.
        """
        ALLOW = 2
        """
        Allow / Force the event. The action indicated by the event will
        take place if possible, even if the server would not normally allow
        the action. Some actions may not be allowed.
        """



from .UnicodeEscaper import UnicodeEscaper
from .Platform import Platform
from .ParametricNullness import ParametricNullness
from .Escapers import Escapers
from .Escaper import Escaper
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .CharEscaperBuilder import CharEscaperBuilder
from .CharEscaper import CharEscaper
from .ArrayBasedUnicodeEscaper import ArrayBasedUnicodeEscaper
from .ArrayBasedEscaperMap import ArrayBasedEscaperMap
from .ArrayBasedCharEscaper import ArrayBasedCharEscaper


"""
Python module generated from Java source file com.google.common.eventbus.Dispatcher

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Queues
from com.google.common.eventbus import *
from java.util import Iterator
from java.util import Queue
from java.util.concurrent import ConcurrentLinkedQueue
from typing import Any, Callable, Iterable, Tuple


class Dispatcher:
    """
    Handler for dispatching events to subscribers, providing different event ordering guarantees that
    make sense for different situations.
    
    **Note:** The dispatcher is orthogonal to the subscriber's `Executor`. The dispatcher
    controls the order in which events are dispatched, while the executor controls how (i.e. on which
    thread) the subscriber is actually called when an event is dispatched to it.

    Author(s)
    - Colin Decker
    """





"""
Python module generated from Java source file org.bukkit.entity.EnderCrystal

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class EnderCrystal(Entity):
    """
    A crystal that heals nearby EnderDragons
    """

    def isShowingBottom(self) -> bool:
        """
        Return whether or not this end crystal is showing the
        bedrock slate underneath it.

        Returns
        - True if the bottom is being shown
        """
        ...


    def setShowingBottom(self, showing: bool) -> None:
        """
        Sets whether or not this end crystal is showing the
        bedrock slate underneath it.

        Arguments
        - showing: whether the bedrock slate should be shown
        """
        ...


    def getBeamTarget(self) -> "Location":
        """
        Gets the location that this end crystal is pointing its beam to.

        Returns
        - the location that the beam is pointed to, or null if the beam is not shown
        """
        ...


    def setBeamTarget(self, location: "Location") -> None:
        """
        Sets the location that this end crystal is pointing to. Passing a null
        value will remove the current beam.

        Arguments
        - location: the location to point the beam to

        Raises
        - IllegalArgumentException: for differing worlds
        """
        ...



"""
Python module generated from Java source file org.joml.Random

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class Random:
    """
    Pseudo-random number generator.

    Author(s)
    - Kai Burjack
    """

    def __init__(self):
        """
        Create a new instance of Random and initialize it with a random seed.
        """
        ...


    def __init__(self, seed: int):
        """
        Create a new instance of Random and initialize it with the given `seed`.

        Arguments
        - seed: the seed number
        """
        ...


    @staticmethod
    def newSeed() -> int:
        ...


    def nextFloat(self) -> float:
        """
        Generate a uniformly distributed floating-point number in the half-open range [0, 1).

        Returns
        - a random float in the range [0..1)
        """
        ...


    def nextInt(self, n: int) -> int:
        """
        Generate a uniformly distributed integer in the half-open range [0, n).

        Arguments
        - n: the upper limit (exclusive) of the generated integer

        Returns
        - a random integer in the range [0..n)
        """
        ...



from .Reference import Reference
from .ReferenceQueue import ReferenceQueue
from .WeakReference import WeakReference
from .SoftReference import SoftReference
from .PhantomReference import PhantomReference


"""
Python module generated from Java source file com.google.common.util.concurrent.ExecutionList

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations.concurrent import GuardedBy
from java.util.concurrent import Executor
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ExecutionList:
    """
    A support class for `ListenableFuture` implementations to manage their listeners. An
    instance contains a list of listeners, each with an associated `Executor`, and guarantees
    that every `Runnable` that is .add added will be executed after .execute() is called. Any `Runnable` added after the call to `execute` is still
    guaranteed to execute. There is no guarantee, however, that listeners will be executed in the
    order that they are added.
    
    Exceptions thrown by a listener will be propagated up to the executor. Any exception thrown
    during `Executor.execute` (e.g., a `RejectedExecutionException` or an exception
    thrown by MoreExecutors.directExecutor direct execution) will be caught and logged.

    Author(s)
    - Sven Mawson

    Since
    - 1.0
    """

    def __init__(self):
        """
        Creates a new, empty ExecutionList.
        """
        ...


    def add(self, runnable: "Runnable", executor: "Executor") -> None:
        """
        Adds the `Runnable` and accompanying `Executor` to the list of listeners to
        execute. If execution has already begun, the listener is executed immediately.
        
        When selecting an executor, note that `directExecutor` is dangerous in some cases. See
        the discussion in the ListenableFuture.addListener ListenableFuture.addListener
        documentation.
        """
        ...


    def execute(self) -> None:
        """
        Runs this execution list, executing all existing pairs in the order they were added. However,
        note that listeners added after this point may be executed before those previously added, and
        note that the execution order of all listeners is ultimately chosen by the implementations of
        the supplied executors.
        
        This method is idempotent. Calling it several times in parallel is semantically equivalent
        to calling it exactly once.

        Since
        - 10.0 (present in 1.0 as `run`)
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Camel

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Camel(AbstractHorse, Sittable):
    """
    Represents a Camel.
    """

    def isDashing(self) -> bool:
        """
        Gets whether this camel is dashing (sprinting).

        Returns
        - dashing status
        """
        ...


    def setDashing(self, dashing: bool) -> None:
        """
        Sets whether this camel is dashing (sprinting).

        Arguments
        - dashing: new dashing status
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.TrustedListenableFutureTask

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from com.google.j2objc.annotations import WeakOuter
from java.util.concurrent import Callable
from java.util.concurrent import Executors
from java.util.concurrent import RunnableFuture
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class TrustedListenableFutureTask(TrustedFuture, RunnableFuture):
    """
    A RunnableFuture that also implements the ListenableFuture interface.
    
    This should be used in preference to ListenableFutureTask when possible for
    performance reasons.
    """

    def run(self) -> None:
        ...



"""
Python module generated from Java source file com.google.common.graph.Graphs

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Objects
from com.google.common.collect import ImmutableSet
from com.google.common.collect import Iterables
from com.google.common.collect import Iterators
from com.google.common.collect import Maps
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import ArrayDeque
from java.util import Deque
from java.util import Iterator
from java.util import Optional
from java.util import Queue
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Graphs(GraphsBridgeMethods):
    """
    Static utility methods for Graph, ValueGraph, and Network instances.

    Author(s)
    - Joshua O'Madadhain

    Since
    - 20.0
    """

    @staticmethod
    def hasCycle(graph: "Graph"["N"]) -> bool:
        """
        Returns True if `graph` has at least one cycle. A cycle is defined as a non-empty subset
        of edges in a graph arranged to form a path (a sequence of adjacent outgoing edges) starting
        and ending with the same node.
        
        This method will detect any non-empty cycle, including self-loops (a cycle of length 1).
        """
        ...


    @staticmethod
    def hasCycle(network: "Network"[Any, Any]) -> bool:
        """
        Returns True if `network` has at least one cycle. A cycle is defined as a non-empty
        subset of edges in a graph arranged to form a path (a sequence of adjacent outgoing edges)
        starting and ending with the same node.
        
        This method will detect any non-empty cycle, including self-loops (a cycle of length 1).
        """
        ...


    @staticmethod
    def transitiveClosure(graph: "Graph"["N"]) -> "ImmutableGraph"["N"]:
        ...


    @staticmethod
    def reachableNodes(graph: "Graph"["N"], node: "N") -> "ImmutableSet"["N"]:
        """
        Returns the set of nodes that are reachable from `node`. Node B is defined as reachable
        from node A if there exists a path (a sequence of adjacent outgoing edges) starting at node A
        and ending at node B. Note that a node is always reachable from itself via a zero-length path.
        
        This is a "snapshot" based on the current topology of `graph`, rather than a live view
        of the set of nodes reachable from `node`. In other words, the returned Set will
        not be updated after modifications to `graph`.

        Raises
        - IllegalArgumentException: if `node` is not present in `graph`

        Since
        - 33.1.0 (present with return type `Set` since 20.0)
        """
        ...


    @staticmethod
    def transpose(graph: "Graph"["N"]) -> "Graph"["N"]:
        """
        Returns a view of `graph` with the direction (if any) of every edge reversed. All other
        properties remain intact, and further updates to `graph` will be reflected in the view.
        """
        ...


    @staticmethod
    def transpose(graph: "ValueGraph"["N", "V"]) -> "ValueGraph"["N", "V"]:
        """
        Returns a view of `graph` with the direction (if any) of every edge reversed. All other
        properties remain intact, and further updates to `graph` will be reflected in the view.
        """
        ...


    @staticmethod
    def transpose(network: "Network"["N", "E"]) -> "Network"["N", "E"]:
        """
        Returns a view of `network` with the direction (if any) of every edge reversed. All other
        properties remain intact, and further updates to `network` will be reflected in the view.
        """
        ...


    @staticmethod
    def inducedSubgraph(graph: "Graph"["N"], nodes: Iterable["N"]) -> "MutableGraph"["N"]:
        """
        Returns the subgraph of `graph` induced by `nodes`. This subgraph is a new graph
        that contains all of the nodes in `nodes`, and all of the Graph.edges() edges
        from `graph` for which both nodes are contained by `nodes`.

        Raises
        - IllegalArgumentException: if any element in `nodes` is not a node in the graph
        """
        ...


    @staticmethod
    def inducedSubgraph(graph: "ValueGraph"["N", "V"], nodes: Iterable["N"]) -> "MutableValueGraph"["N", "V"]:
        """
        Returns the subgraph of `graph` induced by `nodes`. This subgraph is a new graph
        that contains all of the nodes in `nodes`, and all of the Graph.edges() edges
        (and associated edge values) from `graph` for which both nodes are contained by `nodes`.

        Raises
        - IllegalArgumentException: if any element in `nodes` is not a node in the graph
        """
        ...


    @staticmethod
    def inducedSubgraph(network: "Network"["N", "E"], nodes: Iterable["N"]) -> "MutableNetwork"["N", "E"]:
        """
        Returns the subgraph of `network` induced by `nodes`. This subgraph is a new graph
        that contains all of the nodes in `nodes`, and all of the Network.edges() edges
        from `network` for which the Network.incidentNodes(Object) incident nodes are
        both contained by `nodes`.

        Raises
        - IllegalArgumentException: if any element in `nodes` is not a node in the graph
        """
        ...


    @staticmethod
    def copyOf(graph: "Graph"["N"]) -> "MutableGraph"["N"]:
        """
        Creates a mutable copy of `graph` with the same nodes and edges.
        """
        ...


    @staticmethod
    def copyOf(graph: "ValueGraph"["N", "V"]) -> "MutableValueGraph"["N", "V"]:
        """
        Creates a mutable copy of `graph` with the same nodes, edges, and edge values.
        """
        ...


    @staticmethod
    def copyOf(network: "Network"["N", "E"]) -> "MutableNetwork"["N", "E"]:
        """
        Creates a mutable copy of `network` with the same nodes and edges.
        """
        ...



"""
Python module generated from Java source file java.util.PrimitiveIterator

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from java.util.function import Consumer
from java.util.function import DoubleConsumer
from java.util.function import IntConsumer
from java.util.function import LongConsumer
from typing import Any, Callable, Iterable, Tuple


class PrimitiveIterator(Iterator):
    """
    A base type for primitive specializations of `Iterator`.  Specialized
    subtypes are provided for OfInt int, OfLong long, and
    OfDouble double values.
    
    The specialized subtype default implementations of Iterator.next
    and Iterator.forEachRemaining(java.util.function.Consumer) box
    primitive values to instances of their corresponding wrapper class.  Such
    boxing may offset any advantages gained when using the primitive
    specializations.  To avoid boxing, the corresponding primitive-based methods
    should be used.  For example, PrimitiveIterator.OfInt.nextInt() and
    PrimitiveIterator.OfInt.forEachRemaining(java.util.function.IntConsumer)
    should be used in preference to PrimitiveIterator.OfInt.next() and
    PrimitiveIterator.OfInt.forEachRemaining(java.util.function.Consumer).
    
    Iteration of primitive values using boxing-based methods
    Iterator.next next() and
    Iterator.forEachRemaining(java.util.function.Consumer) forEachRemaining(),
    does not affect the order in which the values, transformed to boxed values,
    are encountered.
    
    Type `<T>`: the type of elements returned by this PrimitiveIterator.  The
           type must be a wrapper type for a primitive type, such as
           `Integer` for the primitive `int` type.

    Arguments
    - <T_CONS>: the type of primitive consumer.  The type must be a
           primitive specialization of java.util.function.Consumer for
           `T`, such as java.util.function.IntConsumer for
           `Integer`.

    Since
    - 1.8

    Unknown Tags
    - If the boolean system property `org.openjdk.java.util.stream.tripwire`
    is set to `True` then diagnostic warnings are reported if boxing of
    primitive values occur when operating on primitive subtype specializations.
    """

    def forEachRemaining(self, action: "T_CONS") -> None:
        """
        Performs the given action for each remaining element until all elements
        have been processed or the action throws an exception.  Actions are
        performed in the order of iteration, if that order is specified.
        Exceptions thrown by the action are relayed to the caller.
        
        The behavior of an iterator is unspecified if the action modifies the
        source of elements in any way (even by calling the .remove remove
        method or other mutator methods of `Iterator` subtypes),
        unless an overriding class has specified a concurrent modification policy.
        
        Subsequent behavior of an iterator is unspecified if the action throws an
        exception.

        Arguments
        - action: The action to be performed for each element

        Raises
        - NullPointerException: if the specified action is null
        """
        ...


    class OfInt(PrimitiveIterator):
        """
        An Iterator specialized for `int` values.

        Since
        - 1.8
        """

        def nextInt(self) -> int:
            """
            Returns the next `int` element in the iteration.

            Returns
            - the next `int` element in the iteration

            Raises
            - NoSuchElementException: if the iteration has no more elements
            """
            ...


        def forEachRemaining(self, action: "IntConsumer") -> None:
            """
            Unknown Tags
            - The default implementation behaves as if:
            ````while (hasNext())
                    action.accept(nextInt());````
            """
            ...


        def next(self) -> "Integer":
            """
            Unknown Tags
            - The default implementation boxes the result of calling
            .nextInt(), and returns that boxed result.
            """
            ...


        def forEachRemaining(self, action: "Consumer"["Integer"]) -> None:
            """
            Unknown Tags
            - If the action is an instance of `IntConsumer` then it is cast
            to `IntConsumer` and passed to .forEachRemaining;
            otherwise the action is adapted to an instance of
            `IntConsumer`, by boxing the argument of `IntConsumer`,
            and then passed to .forEachRemaining.
            """
            ...


    class OfLong(PrimitiveIterator):
        """
        An Iterator specialized for `long` values.

        Since
        - 1.8
        """

        def nextLong(self) -> int:
            """
            Returns the next `long` element in the iteration.

            Returns
            - the next `long` element in the iteration

            Raises
            - NoSuchElementException: if the iteration has no more elements
            """
            ...


        def forEachRemaining(self, action: "LongConsumer") -> None:
            """
            Unknown Tags
            - The default implementation behaves as if:
            ````while (hasNext())
                    action.accept(nextLong());````
            """
            ...


        def next(self) -> "Long":
            """
            Unknown Tags
            - The default implementation boxes the result of calling
            .nextLong(), and returns that boxed result.
            """
            ...


        def forEachRemaining(self, action: "Consumer"["Long"]) -> None:
            """
            Unknown Tags
            - If the action is an instance of `LongConsumer` then it is cast
            to `LongConsumer` and passed to .forEachRemaining;
            otherwise the action is adapted to an instance of
            `LongConsumer`, by boxing the argument of `LongConsumer`,
            and then passed to .forEachRemaining.
            """
            ...


    class OfDouble(PrimitiveIterator):
        """
        An Iterator specialized for `double` values.

        Since
        - 1.8
        """

        def nextDouble(self) -> float:
            """
            Returns the next `double` element in the iteration.

            Returns
            - the next `double` element in the iteration

            Raises
            - NoSuchElementException: if the iteration has no more elements
            """
            ...


        def forEachRemaining(self, action: "DoubleConsumer") -> None:
            """
            Unknown Tags
            - The default implementation behaves as if:
            ````while (hasNext())
                    action.accept(nextDouble());````
            """
            ...


        def next(self) -> "Double":
            """
            Unknown Tags
            - The default implementation boxes the result of calling
            .nextDouble(), and returns that boxed result.
            """
            ...


        def forEachRemaining(self, action: "Consumer"["Double"]) -> None:
            """
            Unknown Tags
            - If the action is an instance of `DoubleConsumer` then it is
            cast to `DoubleConsumer` and passed to
            .forEachRemaining; otherwise the action is adapted to
            an instance of `DoubleConsumer`, by boxing the argument of
            `DoubleConsumer`, and then passed to
            .forEachRemaining.
            """
            ...



"""
Python module generated from Java source file com.google.common.graph.DirectedGraphConnections

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Function
from com.google.common.collect import AbstractIterator
from com.google.common.collect import ImmutableList
from com.google.common.collect import Iterators
from com.google.common.collect import UnmodifiableIterator
from com.google.common.graph import *
from java.util import AbstractSet
from java.util import Collections
from java.util import Iterator
from java.util.concurrent.atomic import AtomicBoolean
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class DirectedGraphConnections(GraphConnections):
    """
    An implementation of GraphConnections for directed graphs.
    
    Type `<N>`: Node parameter type
    
    Type `<V>`: Value parameter type

    Author(s)
    - Jens Nyman
    """

    def adjacentNodes(self) -> set["N"]:
        ...


    def predecessors(self) -> set["N"]:
        ...


    def successors(self) -> set["N"]:
        ...


    def incidentEdgeIterator(self, thisNode: "N") -> Iterator["EndpointPair"["N"]]:
        ...


    def value(self, node: "N") -> "V":
        ...


    def removePredecessor(self, node: "N") -> None:
        ...


    def removeSuccessor(self, node: "Object") -> "V":
        ...


    def addPredecessor(self, node: "N", unused: "V") -> None:
        ...


    def addSuccessor(self, node: "N", value: "V") -> "V":
        ...



"""
Python module generated from Java source file com.google.common.collect.CompactLinkedHashMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import WeakOuter
from java.util import Arrays
from java.util import Spliterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CompactLinkedHashMap(CompactHashMap):
    """
    CompactLinkedHashMap is an implementation of a Map with insertion or LRU iteration order,
    maintained with a doubly linked list through the entries. All optional operations (put and
    remove) are supported. Null keys and values are supported.
    
    `containsKey(k)`, `put(k, v)` and `remove(k)` are all (expected and
    amortized) constant time operations. Expected in the hashtable sense (depends on the hash
    function doing a good job of distributing the elements to the buckets to a distribution not far
    from uniform), and amortized since some operations can trigger a hash table resize.
    
    As compared with java.util.LinkedHashMap, this structure places significantly reduced
    load on the garbage collector by only using a constant number of internal objects.
    
    This class should not be assumed to be universally superior to `java.util.LinkedHashMap`. Generally speaking, this class reduces object allocation and memory
    consumption at the price of moderately increased constant factors of CPU. Only use this class
    when there is a specific reason to prioritize memory over CPU.

    Author(s)
    - Louis Wasserman
    """

    @staticmethod
    def create() -> "CompactLinkedHashMap"["K", "V"]:
        """
        Creates an empty `CompactLinkedHashMap` instance.
        """
        ...


    @staticmethod
    def createWithExpectedSize(expectedSize: int) -> "CompactLinkedHashMap"["K", "V"]:
        """
        Creates a `CompactLinkedHashMap` instance, with a high enough "initial capacity" that it
        *should* hold `expectedSize` elements without rebuilding internal data structures.

        Arguments
        - expectedSize: the number of elements you expect to add to the returned set

        Returns
        - a new, empty `CompactLinkedHashMap` with enough capacity to hold `expectedSize` elements without resizing

        Raises
        - IllegalArgumentException: if `expectedSize` is negative
        """
        ...


    def clear(self) -> None:
        ...



"""
Python module generated from Java source file org.joml.sampling.StratifiedSampling

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.joml import Random
from org.joml.sampling import *
from typing import Any, Callable, Iterable, Tuple


class StratifiedSampling:
    """
    Creates samples on a unit quad using an NxN strata grid.

    Author(s)
    - Kai Burjack
    """

    def __init__(self, seed: int):
        """
        Create a new instance of StratifiedSampling and initialize the random number generator with the given
        `seed`.

        Arguments
        - seed: the seed to initialize the random number generator with
        """
        ...


    def generateRandom(self, n: int, callback: "Callback2d") -> None:
        """
        Generate `n * n` random sample positions in the unit square of `x, y = [-1..+1]`.
        
        Each sample within its stratum is distributed randomly.

        Arguments
        - n: the number of strata in each dimension
        - callback: will be called for each generated sample position
        """
        ...


    def generateCentered(self, n: int, centering: float, callback: "Callback2d") -> None:
        """
        Generate `n * n` random sample positions in the unit square of `x, y = [-1..+1]`.
        
        Each sample within its stratum is confined to be within `[-centering/2..1-centering]` of its stratum.

        Arguments
        - n: the number of strata in each dimension
        - centering: determines how much the random samples in each stratum are confined to be near the center of the
                   stratum. Possible values are `[0..1]`
        - callback: will be called for each generated sample position
        """
        ...



"""
Python module generated from Java source file java.io.FileNotFoundException

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class FileNotFoundException(IOException):

    def __init__(self):
        """
        Constructs a `FileNotFoundException` with
        `null` as its error detail message.
        """
        ...


    def __init__(self, s: str):
        """
        Constructs a `FileNotFoundException` with the
        specified detail message. The string `s` can be
        retrieved later by the
        java.lang.Throwable.getMessage
        method of class `java.lang.Throwable`.

        Arguments
        - s: the detail message.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.reader.ReaderException

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.reader import *
from typing import Any, Callable, Iterable, Tuple


class ReaderException(YAMLException):

    def __init__(self, name: str, position: int, codePoint: int, message: str):
        ...


    def getName(self) -> str:
        ...


    def getCodePoint(self) -> int:
        ...


    def getPosition(self) -> int:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.collect.MultimapBuilder

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Supplier
from com.google.common.collect import *
from java.io import Serializable
from java.util import Comparator
from java.util import EnumMap
from java.util import EnumSet
from java.util import SortedSet
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class MultimapBuilder:
    """
    An immutable builder for Multimap instances, letting you independently select the desired
    behaviors (for example, ordering) of the backing map and value-collections. Example:
    
    ````ListMultimap<UserId, ErrorResponse> errorsByUser =
        MultimapBuilder.linkedHashKeys().arrayListValues().build();
    SortedSetMultimap<String, Method> methodsForName =
        MultimapBuilder.treeKeys().treeSetValues(this::compareMethods).build();````
    
    `MultimapBuilder` instances are immutable. Invoking a configuration method has no effect
    on the receiving instance; you must store and use the new builder instance it returns instead.
    
    The generated multimaps are serializable if the key and value types are serializable, unless
    stated otherwise in one of the configuration methods.

    Author(s)
    - Louis Wasserman

    Arguments
    - <K0>: An upper bound on the key type of the generated multimap.
    - <V0>: An upper bound on the value type of the generated multimap.

    Since
    - 16.0
    """

    @staticmethod
    def hashKeys() -> "MultimapBuilderWithKeys"["Object"]:
        """
        Uses a hash table to map keys to value collections.
        """
        ...


    @staticmethod
    def hashKeys(expectedKeys: int) -> "MultimapBuilderWithKeys"["Object"]:
        """
        Uses a hash table to map keys to value collections, initialized to expect the specified number
        of keys.

        Raises
        - IllegalArgumentException: if `expectedKeys < 0`
        """
        ...


    @staticmethod
    def linkedHashKeys() -> "MultimapBuilderWithKeys"["Object"]:
        """
        Uses a hash table to map keys to value collections.
        
        The collections returned by Multimap.keySet(), Multimap.keys(), and Multimap.asMap() will iterate through the keys in the order that they were first added to the
        multimap, save that if all values associated with a key are removed and then the key is added
        back into the multimap, that key will come last in the key iteration order.
        """
        ...


    @staticmethod
    def linkedHashKeys(expectedKeys: int) -> "MultimapBuilderWithKeys"["Object"]:
        """
        Uses an hash table to map keys to value collections, initialized to expect the specified number
        of keys.
        
        The collections returned by Multimap.keySet(), Multimap.keys(), and Multimap.asMap() will iterate through the keys in the order that they were first added to the
        multimap, save that if all values associated with a key are removed and then the key is added
        back into the multimap, that key will come last in the key iteration order.
        """
        ...


    @staticmethod
    def treeKeys() -> "MultimapBuilderWithKeys"["Comparable"]:
        """
        Uses a naturally-ordered TreeMap to map keys to value collections.
        
        The collections returned by Multimap.keySet(), Multimap.keys(), and Multimap.asMap() will iterate through the keys in sorted order.
        
        For all multimaps generated by the resulting builder, the Multimap.keySet() can be
        safely cast to a java.util.SortedSet, and the Multimap.asMap() can safely be
        cast to a java.util.SortedMap.
        """
        ...


    @staticmethod
    def treeKeys(comparator: "Comparator"["K0"]) -> "MultimapBuilderWithKeys"["K0"]:
        """
        Uses a TreeMap sorted by the specified comparator to map keys to value collections.
        
        The collections returned by Multimap.keySet(), Multimap.keys(), and Multimap.asMap() will iterate through the keys in sorted order.
        
        For all multimaps generated by the resulting builder, the Multimap.keySet() can be
        safely cast to a java.util.SortedSet, and the Multimap.asMap() can safely be
        cast to a java.util.SortedMap.
        
        Multimaps generated by the resulting builder will not be serializable if `comparator`
        is not serializable.
        """
        ...


    @staticmethod
    def enumKeys(keyClass: type["K0"]) -> "MultimapBuilderWithKeys"["K0"]:
        """
        Uses an EnumMap to map keys to value collections.

        Since
        - 16.0
        """
        ...


    def build(self) -> "Multimap"["K", "V"]:
        """
        Returns a new, empty `Multimap` with the specified implementation.
        """
        ...


    def build(self, multimap: "Multimap"["K", "V"]) -> "Multimap"["K", "V"]:
        """
        Returns a `Multimap` with the specified implementation, initialized with the entries of
        `multimap`.
        """
        ...


    class MultimapBuilderWithKeys:
        """
        An intermediate stage in a MultimapBuilder in which the key-value collection map
        implementation has been specified, but the value collection implementation has not.

        Arguments
        - <K0>: The upper bound on the key type of the generated multimap.

        Since
        - 16.0
        """

        def arrayListValues(self) -> "ListMultimapBuilder"["K0", "Object"]:
            """
            Uses an ArrayList to store value collections.
            """
            ...


        def arrayListValues(self, expectedValuesPerKey: int) -> "ListMultimapBuilder"["K0", "Object"]:
            """
            Uses an ArrayList to store value collections, initialized to expect the specified
            number of values per key.

            Raises
            - IllegalArgumentException: if `expectedValuesPerKey < 0`
            """
            ...


        def linkedListValues(self) -> "ListMultimapBuilder"["K0", "Object"]:
            """
            Uses a LinkedList to store value collections.
            """
            ...


        def hashSetValues(self) -> "SetMultimapBuilder"["K0", "Object"]:
            """
            Uses a hash-based `Set` to store value collections.
            """
            ...


        def hashSetValues(self, expectedValuesPerKey: int) -> "SetMultimapBuilder"["K0", "Object"]:
            """
            Uses a hash-based `Set` to store value collections, initialized to expect the specified
            number of values per key.

            Raises
            - IllegalArgumentException: if `expectedValuesPerKey < 0`
            """
            ...


        def linkedHashSetValues(self) -> "SetMultimapBuilder"["K0", "Object"]:
            """
            Uses an insertion-ordered hash-based `Set` to store value collections.
            """
            ...


        def linkedHashSetValues(self, expectedValuesPerKey: int) -> "SetMultimapBuilder"["K0", "Object"]:
            """
            Uses an insertion-ordered hash-based `Set` to store value collections, initialized to
            expect the specified number of values per key.

            Raises
            - IllegalArgumentException: if `expectedValuesPerKey < 0`
            """
            ...


        def treeSetValues(self) -> "SortedSetMultimapBuilder"["K0", "Comparable"]:
            """
            Uses a naturally-ordered TreeSet to store value collections.
            """
            ...


        def treeSetValues(self, comparator: "Comparator"["V0"]) -> "SortedSetMultimapBuilder"["K0", "V0"]:
            """
            Uses a TreeSet ordered by the specified comparator to store value collections.
            
            Multimaps generated by the resulting builder will not be serializable if `comparator` is not serializable.
            """
            ...


        def enumSetValues(self, valueClass: type["V0"]) -> "SetMultimapBuilder"["K0", "V0"]:
            """
            Uses an EnumSet to store value collections.
            """
            ...


    class ListMultimapBuilder(MultimapBuilder):
        """
        A specialization of MultimapBuilder that generates ListMultimap instances.

        Since
        - 16.0
        """

        def build(self) -> "ListMultimap"["K", "V"]:
            ...


        def build(self, multimap: "Multimap"["K", "V"]) -> "ListMultimap"["K", "V"]:
            ...


    class SetMultimapBuilder(MultimapBuilder):
        """
        A specialization of MultimapBuilder that generates SetMultimap instances.

        Since
        - 16.0
        """

        def build(self) -> "SetMultimap"["K", "V"]:
            ...


        def build(self, multimap: "Multimap"["K", "V"]) -> "SetMultimap"["K", "V"]:
            ...


    class SortedSetMultimapBuilder(SetMultimapBuilder):
        """
        A specialization of MultimapBuilder that generates SortedSetMultimap instances.

        Since
        - 16.0
        """

        def build(self) -> "SortedSetMultimap"["K", "V"]:
            ...


        def build(self, multimap: "Multimap"["K", "V"]) -> "SortedSetMultimap"["K", "V"]:
            ...



"""
Python module generated from Java source file com.google.common.base.Utf8

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from typing import Any, Callable, Iterable, Tuple


class Utf8:
    """
    Low-level, high-performance utility methods related to the Charsets.UTF_8 UTF-8
    character encoding. UTF-8 is defined in section D92 of <a
    href="http://www.unicode.org/versions/Unicode6.2.0/ch03.pdf">The Unicode Standard Core
    Specification, Chapter 3</a>.
    
    The variant of UTF-8 implemented by this class is the restricted definition of UTF-8
    introduced in Unicode 3.1. One implication of this is that it rejects <a
    href="http://www.unicode.org/versions/corrigendum1.html">"non-shortest form"</a> byte sequences,
    even though the JDK decoder may accept them.

    Author(s)
    - Clément Roux

    Since
    - 16.0
    """

    @staticmethod
    def encodedLength(sequence: "CharSequence") -> int:
        """
        Returns the number of bytes in the UTF-8-encoded form of `sequence`. For a string, this
        method is equivalent to `string.getBytes(UTF_8).length`, but is more efficient in both
        time and space.

        Raises
        - IllegalArgumentException: if `sequence` contains ill-formed UTF-16 (unpaired
            surrogates)
        """
        ...


    @staticmethod
    def isWellFormed(bytes: list[int]) -> bool:
        """
        Returns `True` if `bytes` is a *well-formed* UTF-8 byte sequence according to
        Unicode 6.0. Note that this is a stronger criterion than simply whether the bytes can be
        decoded. For example, some versions of the JDK decoder will accept "non-shortest form" byte
        sequences, but encoding never reproduces these. Such byte sequences are *not* considered
        well-formed.
        
        This method returns `True` if and only if `Arrays.equals(bytes, new
        String(bytes, UTF_8).getBytes(UTF_8))` does, but is more efficient in both time and space.
        """
        ...


    @staticmethod
    def isWellFormed(bytes: list[int], off: int, len: int) -> bool:
        """
        Returns whether the given byte array slice is a well-formed UTF-8 byte sequence, as defined by
        .isWellFormed(byte[]). Note that this can be False even when `isWellFormed(bytes)` is True.

        Arguments
        - bytes: the input buffer
        - off: the offset in the buffer of the first byte to read
        - len: the number of bytes to read from the buffer
        """
        ...



"""
Python module generated from Java source file java.util.StringTokenizer

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class StringTokenizer(Enumeration):
    """
    The string tokenizer class allows an application to break a
    string into tokens. The tokenization method is much simpler than
    the one used by the `StreamTokenizer` class. The
    `StringTokenizer` methods do not distinguish among
    identifiers, numbers, and quoted strings, nor do they recognize
    and skip comments.
    
    The set of delimiters (the characters that separate tokens) may
    be specified either at creation time or on a per-token basis.
    
    An instance of `StringTokenizer` behaves in one of two
    ways, depending on whether it was created with the
    `returnDelims` flag having the value `True`
    or `False`:
    
    - If the flag is `False`, delimiter characters serve to
        separate tokens. A token is a maximal sequence of consecutive
        characters that are not delimiters.
    - If the flag is `True`, delimiter characters are themselves
        considered to be tokens. A token is thus either one delimiter
        character, or a maximal sequence of consecutive characters that are
        not delimiters.
    
    A `StringTokenizer` object internally maintains a current
    position within the string to be tokenized. Some operations advance this
    current position past the characters processed.
    A token is returned by taking a substring of the string that was used to
    create the `StringTokenizer` object.
    
    The following is one example of the use of the tokenizer. The code:
    <blockquote>```
        StringTokenizer st = new StringTokenizer("this is a test");
        while (st.hasMoreTokens()) {
            System.out.println(st.nextToken());
        }
    ```</blockquote>
    
    prints the following output:
    <blockquote>```
        this
        is
        a
        test
    ```</blockquote>
    
    
    `StringTokenizer` is a legacy class that is retained for
    compatibility reasons although its use is discouraged in new code. It is
    recommended that anyone seeking this functionality use the `split`
    method of `String` or the java.util.regex package instead.
    
    The following example illustrates how the `String.split`
    method can be used to break up a string into its basic tokens:
    <blockquote>```
        String[] result = "this is a test".split("\\s");
        for (int x=0; x&lt;result.length; x++)
            System.out.println(result[x]);
    ```</blockquote>
    
    prints the following output:
    <blockquote>```
        this
        is
        a
        test
    ```</blockquote>

    See
    - java.io.StreamTokenizer

    Since
    - 1.0
    """

    def __init__(self, str: str, delim: str, returnDelims: bool):
        """
        Constructs a string tokenizer for the specified string. All
        characters in the `delim` argument are the delimiters
        for separating tokens.
        
        If the `returnDelims` flag is `True`, then
        the delimiter characters are also returned as tokens. Each
        delimiter is returned as a string of length one. If the flag is
        `False`, the delimiter characters are skipped and only
        serve as separators between tokens.
        
        Note that if `delim` is `null`, this constructor does
        not throw an exception. However, trying to invoke other methods on the
        resulting `StringTokenizer` may result in a
        `NullPointerException`.

        Arguments
        - str: a string to be parsed.
        - delim: the delimiters.
        - returnDelims: flag indicating whether to return the delimiters
                                as tokens.

        Raises
        - NullPointerException: if str is `null`
        """
        ...


    def __init__(self, str: str, delim: str):
        """
        Constructs a string tokenizer for the specified string. The
        characters in the `delim` argument are the delimiters
        for separating tokens. Delimiter characters themselves will not
        be treated as tokens.
        
        Note that if `delim` is `null`, this constructor does
        not throw an exception. However, trying to invoke other methods on the
        resulting `StringTokenizer` may result in a
        `NullPointerException`.

        Arguments
        - str: a string to be parsed.
        - delim: the delimiters.

        Raises
        - NullPointerException: if str is `null`
        """
        ...


    def __init__(self, str: str):
        """
        Constructs a string tokenizer for the specified string. The
        tokenizer uses the default delimiter set, which is
        `"&nbsp;&#92;t&#92;n&#92;r&#92;f"`: the space character,
        the tab character, the newline character, the carriage-return character,
        and the form-feed character. Delimiter characters themselves will
        not be treated as tokens.

        Arguments
        - str: a string to be parsed.

        Raises
        - NullPointerException: if str is `null`
        """
        ...


    def hasMoreTokens(self) -> bool:
        """
        Tests if there are more tokens available from this tokenizer's string.
        If this method returns `True`, then a subsequent call to
        `nextToken` with no argument will successfully return a token.

        Returns
        - `True` if and only if there is at least one token
                 in the string after the current position; `False`
                 otherwise.
        """
        ...


    def nextToken(self) -> str:
        """
        Returns the next token from this string tokenizer.

        Returns
        - the next token from this string tokenizer.

        Raises
        - NoSuchElementException: if there are no more tokens in this
                      tokenizer's string.
        """
        ...


    def nextToken(self, delim: str) -> str:
        """
        Returns the next token in this string tokenizer's string. First,
        the set of characters considered to be delimiters by this
        `StringTokenizer` object is changed to be the characters in
        the string `delim`. Then the next token in the string
        after the current position is returned. The current position is
        advanced beyond the recognized token.  The new delimiter set
        remains the default after this call.

        Arguments
        - delim: the new delimiters.

        Returns
        - the next token, after switching to the new delimiter set.

        Raises
        - NoSuchElementException: if there are no more tokens in this
                      tokenizer's string.
        - NullPointerException: if delim is `null`
        """
        ...


    def hasMoreElements(self) -> bool:
        """
        Returns the same value as the `hasMoreTokens`
        method. It exists so that this class can implement the
        `Enumeration` interface.

        Returns
        - `True` if there are more tokens;
                 `False` otherwise.

        See
        - java.util.StringTokenizer.hasMoreTokens()
        """
        ...


    def nextElement(self) -> "Object":
        """
        Returns the same value as the `nextToken` method,
        except that its declared return value is `Object` rather than
        `String`. It exists so that this class can implement the
        `Enumeration` interface.

        Returns
        - the next token in the string.

        Raises
        - NoSuchElementException: if there are no more tokens in this
                      tokenizer's string.

        See
        - java.util.StringTokenizer.nextToken()
        """
        ...


    def countTokens(self) -> int:
        """
        Calculates the number of times that this tokenizer's
        `nextToken` method can be called before it generates an
        exception. The current position is not advanced.

        Returns
        - the number of tokens remaining in the string using the current
                 delimiter set.

        See
        - java.util.StringTokenizer.nextToken()
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.ThreadFactory

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class ThreadFactory:
    """
    An object that creates new threads on demand.  Using thread factories
    removes hardwiring of calls to Thread.Thread(Runnable) new Thread,
    enabling applications to use special thread subclasses, priorities, etc.
    
    
    The simplest implementation of this interface is just:
    ``` `class SimpleThreadFactory implements ThreadFactory {
      public Thread newThread(Runnable r) {
        return new Thread(r);`
    }}```
    
    The Executors.defaultThreadFactory method provides a more
    useful simple implementation, that sets the created thread context
    to known values before returning it.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def newThread(self, r: "Runnable") -> "Thread":
        """
        Constructs a new `Thread`.  Implementations may also initialize
        priority, name, daemon status, `ThreadGroup`, etc.

        Arguments
        - r: a runnable to be executed by new thread instance

        Returns
        - constructed thread, or `null` if the request to
                create a thread is rejected
        """
        ...



from .HelpCommand import HelpCommand
from .ReloadCommand import ReloadCommand
from .VersionCommand import VersionCommand
from .BukkitCommand import BukkitCommand
from .TimingsCommand import TimingsCommand
from .PluginsCommand import PluginsCommand